@@ -18,15 +18,18 @@ from tlstrust.stores.ccadb import __version__ as ccadb_version
 from tlstrust.stores.java import __version__ as java_version
 from tlstrust.stores.certifi import __version__ as certifi_version
 from tlstrust.stores.linux import __version__ as linux_version
+from tlstrust.stores.android_2_2 import __description__ as android2_2_version
+from tlstrust.stores.android_2_3 import __description__ as android2_3_version
+from tlstrust.stores.android_3 import __description__ as android3_version
+from tlstrust.stores.android_4 import __description__ as android4_version
+from tlstrust.stores.android_4_4 import __description__ as android4_4_version
 from tlstrust.stores.android_7 import __description__ as android7_version
 from tlstrust.stores.android_8 import __description__ as android8_version
 from tlstrust.stores.android_9 import __description__ as android9_version
 from tlstrust.stores.android_10 import __description__ as android10_version
 from tlstrust.stores.android_11 import __description__ as android11_version
 from tlstrust.stores.android_12 import __description__ as android12_version
-from . import util
-from . import pci
-from . import exceptions
+from . import exceptions, util, pci, fips, nist
 from .transport import Transport
 from .metadata import Metadata
 
@@ -178,7 +181,7 @@ class Validator:
 
     def pcidss_compliant(self) -> bool:
         logger.debug('PCI DSS compliance validations')
-        self.validation_checks[pci.VALIDATION_WEAK_KEY] = self.metadata.certificate_public_key_size >= pci.PCI_DSS_WEAK_KEY_SIZE[self.metadata.certificate_public_key_type]
+        self.validation_checks[pci.VALIDATION_WEAK_KEY] = self.metadata.certificate_public_key_size >= pci.WEAK_KEY_SIZE[self.metadata.certificate_public_key_type]
         if self.validation_checks[pci.VALIDATION_WEAK_KEY] is False:
             if self.metadata.certificate_public_key_type == 'RSA':
                 self.certificate_verify_messages.append(pci.PCIDSS_NON_COMPLIANCE_WEAK_KEY_RSA)
@@ -189,6 +192,32 @@ class Validator:
             if self.metadata.certificate_public_key_type == 'DH':
                 self.certificate_verify_messages.append(pci.PCIDSS_NON_COMPLIANCE_WEAK_KEY_DH)
 
+    def fips_compliant(self) -> bool:
+        logger.debug('FIPS compliance validations')
+        self.validation_checks[fips.VALIDATION_WEAK_KEY] = self.metadata.certificate_public_key_size >= fips.WEAK_KEY_SIZE[self.metadata.certificate_public_key_type]
+        if self.validation_checks[fips.VALIDATION_WEAK_KEY] is False:
+            if self.metadata.certificate_public_key_type == 'RSA':
+                self.certificate_verify_messages.append(fips.FIPS_NON_COMPLIANCE_WEAK_KEY_RSA)
+            if self.metadata.certificate_public_key_type == 'DSA':
+                self.certificate_verify_messages.append(fips.FIPS_NON_COMPLIANCE_WEAK_KEY_DSA)
+            if self.metadata.certificate_public_key_type == 'EC':
+                self.certificate_verify_messages.append(fips.FIPS_NON_COMPLIANCE_WEAK_KEY_EC)
+            if self.metadata.certificate_public_key_type == 'DH':
+                self.certificate_verify_messages.append(fips.FIPS_NON_COMPLIANCE_WEAK_KEY_DH)
+
+    def nist_compliant(self) -> bool:
+        logger.debug('NIST compliance validations')
+        self.validation_checks[nist.VALIDATION_WEAK_KEY] = self.metadata.certificate_public_key_size >= nist.WEAK_KEY_SIZE[self.metadata.certificate_public_key_type]
+        if self.validation_checks[nist.VALIDATION_WEAK_KEY] is False:
+            if self.metadata.certificate_public_key_type == 'RSA':
+                self.certificate_verify_messages.append(nist.NIST_NON_COMPLIANCE_WEAK_KEY_RSA)
+            if self.metadata.certificate_public_key_type == 'DSA':
+                self.certificate_verify_messages.append(nist.NIST_NON_COMPLIANCE_WEAK_KEY_DSA)
+            if self.metadata.certificate_public_key_type == 'EC':
+                self.certificate_verify_messages.append(nist.NIST_NON_COMPLIANCE_WEAK_KEY_EC)
+            if self.metadata.certificate_public_key_type == 'DH':
+                self.certificate_verify_messages.append(nist.NIST_NON_COMPLIANCE_WEAK_KEY_DH)
+
     def verify(self) -> bool:
         logger.debug('Common certificate validations')
         not_after = datetime.fromisoformat(self.metadata.certificate_not_after)
@@ -254,6 +283,18 @@ class RootCertValidator(Validator):
         if self.validation_checks[pci.VALIDATION_CA_TRUST] is False:
             self.certificate_verify_messages.append(pci.PCIDSS_NON_COMPLIANCE_CA_TRUST)
 
+    def fips_compliant(self) -> bool:
+        super().fips_compliant()
+        self.validation_checks[fips.VALIDATION_CA_TRUST] = all([self.metadata.trust_ccadb, self.metadata.trust_android, self.metadata.trust_certifi, self.metadata.trust_java, self.metadata.trust_linux])
+        if self.validation_checks[fips.VALIDATION_CA_TRUST] is False:
+            self.certificate_verify_messages.append(fips.FIPS_NON_COMPLIANCE_CA_TRUST)
+
+    def nist_compliant(self) -> bool:
+        super().nist_compliant()
+        self.validation_checks[nist.VALIDATION_CA_TRUST] = all([self.metadata.trust_ccadb, self.metadata.trust_android, self.metadata.trust_certifi, self.metadata.trust_java, self.metadata.trust_linux])
+        if self.validation_checks[nist.VALIDATION_CA_TRUST] is False:
+            self.certificate_verify_messages.append(nist.NIST_NON_COMPLIANCE_CA_TRUST)
+
     def verify_trust(self, trust_store :TrustStore):
         DEFAULT_STATUS = 'No Root CA Certificate in the {platform} Trust Store'
         self.metadata.trust_ccadb_status = DEFAULT_STATUS.format(platform='CCADB')
@@ -281,39 +322,78 @@ class RootCertValidator(Validator):
                 self.metadata.trust_certifi_status += expired_text
 
         android_stores = []
+        if trust_store.exists(context.PLATFORM_ANDROID2_2):
+            android_status = f'{android2_2_version} {"Trusted" if trust_store.android2_2 else "Not Trusted"}'
+            if trust_store.expired_in_store(context.PLATFORM_ANDROID2_2):
+                android_status += expired_text
+            android_stores.append(android_status)
+        else:
+            android_stores.append(f'{android2_2_version} Not Present')
+        if trust_store.exists(context.PLATFORM_ANDROID2_3):
+            android_status = f'{android2_3_version} {"Trusted" if trust_store.android2_3 else "Not Trusted"}'
+            if trust_store.expired_in_store(context.PLATFORM_ANDROID2_3):
+                android_status += expired_text
+            android_stores.append(android_status)
+        else:
+            android_stores.append(f'{android2_3_version} Not Present')
+        if trust_store.exists(context.PLATFORM_ANDROID3):
+            android_status = f'{android3_version} {"Trusted" if trust_store.android3 else "Not Trusted"}'
+            if trust_store.expired_in_store(context.PLATFORM_ANDROID3):
+                android_status += expired_text
+            android_stores.append(android_status)
+        else:
+            android_stores.append(f'{android3_version} Not Present')
+        if trust_store.exists(context.PLATFORM_ANDROID4_4):
+            android_status = f'{android4_4_version} {"Trusted" if trust_store.android4_4 else "Not Trusted"}'
+            if trust_store.expired_in_store(context.PLATFORM_ANDROID4_4):
+                android_status += expired_text
+            android_stores.append(android_status)
+        else:
+            android_stores.append(f'{android4_4_version} Not Present')
         if trust_store.exists(context.PLATFORM_ANDROID7):
-            android_status = android7_version
+            android_status = f'{android7_version} {"Trusted" if trust_store.android7 else "Not Trusted"}'
             if trust_store.expired_in_store(context.PLATFORM_ANDROID7):
                 android_status += expired_text
             android_stores.append(android_status)
+        else:
+            android_stores.append(f'{android7_version} Not Present')
         if trust_store.exists(context.PLATFORM_ANDROID8):
-            android_status = android8_version
+            android_status = f'{android8_version} {"Trusted" if trust_store.android8 else "Not Trusted"}'
             if trust_store.expired_in_store(context.PLATFORM_ANDROID8):
                 android_status += expired_text
             android_stores.append(android_status)
+        else:
+            android_stores.append(f'{android8_version} Not Present')
         if trust_store.exists(context.PLATFORM_ANDROID9):
-            android_status = android9_version
+            android_status = f'{android9_version} {"Trusted" if trust_store.android9 else "Not Trusted"}'
             if trust_store.expired_in_store(context.PLATFORM_ANDROID9):
                 android_status += expired_text
             android_stores.append(android_status)
+        else:
+            android_stores.append(f'{android9_version} Not Present')
         if trust_store.exists(context.PLATFORM_ANDROID10):
-            android_status = android10_version
+            android_status = f'{android10_version} {"Trusted" if trust_store.android10 else "Not Trusted"}'
             if trust_store.expired_in_store(context.PLATFORM_ANDROID10):
                 android_status += expired_text
             android_stores.append(android_status)
+        else:
+            android_stores.append(f'{android10_version} Not Present')
         if trust_store.exists(context.PLATFORM_ANDROID11):
-            android_status = android11_version
+            android_status = f'{android11_version} {"Trusted" if trust_store.android11 else "Not Trusted"}'
             if trust_store.expired_in_store(context.PLATFORM_ANDROID11):
                 android_status += expired_text
             android_stores.append(android_status)
+        else:
+            android_stores.append(f'{android11_version} Not Present')
         if trust_store.exists(context.PLATFORM_ANDROID12):
-            android_status = android12_version
+            android_status = f'{android12_version} {"Trusted" if trust_store.android12 else "Not Trusted"}'
             if trust_store.expired_in_store(context.PLATFORM_ANDROID12):
                 android_status += expired_text
             android_stores.append(android_status)
-        if android_stores:
-            self.metadata.trust_android_status = "\n".join(android_stores)
+        else:
+            android_stores.append(f'{android12_version} Not Present')
 
+        self.metadata.trust_android_status = "\n".join(android_stores)
         self.metadata.trust_ccadb = trust_store.ccadb
         self.metadata.trust_java = trust_store.java
         self.metadata.trust_android = all([trust_store.android7, trust_store.android8, trust_store.android9, trust_store.android10, trust_store.android11, trust_store.android12])
@@ -465,7 +545,7 @@ class CertValidator(Validator):
 
     def pcidss_compliant(self) -> bool:
         super().pcidss_compliant()
-        self.validation_checks[pci.VALIDATION_WEAK_CIPHER] = not self.metadata.weak_cipher or self.metadata.negotiated_cipher_bits >= pci.PCI_DSS_WEAK_CIPHER_BITS
+        self.validation_checks[pci.VALIDATION_WEAK_CIPHER] = not self.metadata.weak_cipher or self.metadata.negotiated_cipher_bits >= pci.WEAK_CIPHER_BITS
         if self.validation_checks[pci.VALIDATION_WEAK_CIPHER] is False:
             self.certificate_verify_messages.append(pci.PCIDSS_NON_COMPLIANCE_CIPHER)
         self.validation_checks[pci.VALIDATION_WEAK_PROTOCOL] = self.metadata.negotiated_protocol not in util.WEAK_PROTOCOL.keys()
@@ -475,8 +555,8 @@ class CertValidator(Validator):
         if self.validation_checks[pci.VALIDATION_DEPRECATED_ALGO] is False:
             self.certificate_verify_messages.append(pci.PCIDSS_NON_COMPLIANCE_WEAK_ALGORITHMS)
         self.validation_checks[pci.VALIDATION_KNOWN_VULN_SESSION_RESUMPTION] = all([
-            not self.metadata.session_resumption_tickets or self.metadata.negotiated_protocol == util.OPENSSL_VERSION_LOOKUP[SSL.TLS1_3_VERSION],
-            not self.metadata.session_resumption_caching or self.metadata.negotiated_protocol == util.OPENSSL_VERSION_LOOKUP[SSL.TLS1_3_VERSION],
+            not self.metadata.session_resumption_tickets or util.PROTOCOL_TEXT_MAP[self.metadata.negotiated_protocol] == SSL.TLS1_3_VERSION,
+            not self.metadata.session_resumption_caching or util.PROTOCOL_TEXT_MAP[self.metadata.negotiated_protocol] == SSL.TLS1_3_VERSION,
         ])
         self.validation_checks[pci.VALIDATION_KNOWN_VULN_RENEGOTIATION] = not self.metadata.client_renegotiation
         self.validation_checks[pci.VALIDATION_KNOWN_VULN_COMPRESSION] = not self.metadata.compression_support
@@ -487,6 +567,45 @@ class CertValidator(Validator):
             ]):
             self.certificate_verify_messages.append(pci.PCIDSS_NON_COMPLIANCE_KNOWN_VULNERABILITIES)
 
+    def fips_compliant(self) -> bool:
+        super().fips_compliant()
+        if util.PROTOCOL_TEXT_MAP[self.metadata.negotiated_protocol] not in [SSL.TLS1_2_VERSION, SSL.TLS1_3_VERSION]:
+            self.validation_checks[fips.VALIDATION_MTLS] = not self.metadata.client_certificate_expected
+
+        self.validation_checks[fips.VALIDATION_WEAK_PROTOCOL] = self.metadata.negotiated_protocol not in ['SSLv2 (0x02ff)', 'SSLv3 (0x0300)']
+        if self.validation_checks[fips.VALIDATION_WEAK_PROTOCOL] is False:
+            self.certificate_verify_messages.append(fips.FIPS_NON_COMPLIANCE_WEAK_PROTOCOL)
+            self.validation_checks[fips.VALIDATION_WEAK_CIPHER] = False
+            self.certificate_verify_messages.append(fips.FIPS_NON_COMPLIANCE_CIPHER)
+        else:
+            ok_cipher = self.metadata.negotiated_cipher_bits >= fips.WEAK_CIPHER_BITS
+            if ok_cipher and util.PROTOCOL_TEXT_MAP[self.metadata.negotiated_protocol] == SSL.TLS1_2_VERSION:
+                ok_cipher = all(c in self.metadata.negotiated_cipher for c in fips.ALLOWED_CIPHERS)
+            if ok_cipher and util.PROTOCOL_TEXT_MAP[self.metadata.negotiated_protocol] in [SSL.TLS1_VERSION, SSL.TLS1_1_VERSION]:
+                ok_cipher = all(c in self.metadata.negotiated_cipher for c in fips.ALLOWED_DEPRECATED_TLS_CIPHERS)
+            self.validation_checks[fips.VALIDATION_WEAK_CIPHER] = ok_cipher
+            if self.validation_checks[fips.VALIDATION_WEAK_CIPHER] is False:
+                self.certificate_verify_messages.append(fips.FIPS_NON_COMPLIANCE_CIPHER)
+
+    def nist_compliant(self) -> bool:
+        # sourcery skip: extract-duplicate-method, extract-method, remove-redundant-if, split-or-ifs
+        # sourcery will add bloat here, this is massively more concise logic then theirs
+        super().nist_compliant()
+        if util.PROTOCOL_TEXT_MAP[self.metadata.negotiated_protocol] in [SSL.TLS1_2_VERSION, SSL.TLS1_3_VERSION]:
+            self.validation_checks[nist.VALIDATION_WEAK_PROTOCOL] = True
+            self.validation_checks[nist.VALIDATION_MTLS] = self.metadata.client_certificate_expected
+            ok_cipher = self.metadata.negotiated_cipher_bits >= nist.WEAK_CIPHER_BITS
+            if ok_cipher and util.PROTOCOL_TEXT_MAP[self.metadata.negotiated_protocol] == SSL.TLS1_2_VERSION:
+                ok_cipher = all(c in self.metadata.negotiated_cipher for c in nist.ALLOWED_CIPHERS)
+            self.validation_checks[nist.VALIDATION_WEAK_CIPHER] = ok_cipher
+            if self.validation_checks[nist.VALIDATION_WEAK_CIPHER] is False:
+                self.certificate_verify_messages.append(nist.NIST_NON_COMPLIANCE_CIPHER)
+        else:
+            self.validation_checks[nist.VALIDATION_WEAK_PROTOCOL] = False
+            self.certificate_verify_messages.append(nist.NIST_NON_COMPLIANCE_WEAK_PROTOCOL)
+            self.validation_checks[nist.VALIDATION_WEAK_CIPHER] = False
+            self.certificate_verify_messages.append(nist.NIST_NON_COMPLIANCE_CIPHER)
+
     def verify(self) -> bool:
         super().verify()
         tldext = TLDExtract(cache_dir='/tmp')(f'http://{self.metadata.host}')
@@ -500,7 +619,7 @@ class CertValidator(Validator):
                 self.certificate_verify_messages.append(exceptions.VALIDATION_ERROR_CLIENT_AUTHENTICATION)
         if isinstance(ca, bool) and ca is True:
             self.validation_checks[VALIDATION_BASIC_CONSTRAINTS_CA] = False
-            self.certificate_verify_messages.append('server certificates should not be a CA, it could enable impersonation attacks')
+            self.certificate_verify_messages.append('Server (leaf) certificates should not be a CA, it could enable impersonation attacks')
         self.validation_checks[VALIDATION_VALID_TLS_USAGE] = util.key_usage_exists(self.certificate, 'digital_signature') is True and util.key_usage_exists(self.certificate, 'serverAuth') is True
         self.validation_checks[VALIDATION_SUBJECT_CN_VALID] = util.validate_common_name(self.metadata.certificate_common_name, self.metadata.host) is True
         self.validation_checks[VALIDATION_MATCH_HOSTNAME] = util.match_hostname(self.metadata.host, self.certificate)
@@ -538,11 +657,11 @@ class CertValidator(Validator):
             self.certificate_verify_messages.append(exceptions.VALIDATION_ERROR_CERTIFICATE_VALIDATION_TYPE)
         if not self.metadata.certification_authority_authorization:
             self.certificate_verify_messages.append(exceptions.VALIDATION_ERROR_CERTIFICATION_AUTHORITY_AUTHORIZATION)
-        if self.metadata.session_resumption_caching and self.metadata.negotiated_protocol != util.OPENSSL_VERSION_LOOKUP[SSL.TLS1_3_VERSION]:
+        if self.metadata.session_resumption_caching and util.PROTOCOL_TEXT_MAP[self.metadata.negotiated_protocol] != SSL.TLS1_3_VERSION:
             self.certificate_verify_messages.append(exceptions.VALIDATION_ERROR_SESSION_RESUMPTION_CACHING)
-        if self.metadata.session_resumption_caching and self.metadata.negotiated_protocol == util.OPENSSL_VERSION_LOOKUP[SSL.TLS1_3_VERSION]:
+        if self.metadata.session_resumption_caching and util.PROTOCOL_TEXT_MAP[self.metadata.negotiated_protocol] == SSL.TLS1_3_VERSION:
             self.certificate_verify_messages.append(exceptions.VALIDATION_ERROR_SESSION_RESUMPTION_CACHING_TLS1_3)
-        if self.metadata.session_resumption_tickets and self.metadata.negotiated_protocol != util.OPENSSL_VERSION_LOOKUP[SSL.TLS1_3_VERSION]:
+        if self.metadata.session_resumption_tickets and util.PROTOCOL_TEXT_MAP[self.metadata.negotiated_protocol] != SSL.TLS1_3_VERSION:
             self.certificate_verify_messages.append(exceptions.VALIDATION_ERROR_SESSION_RESUMPTION_TICKETS)
         if self.metadata.client_renegotiation:
             self.certificate_verify_messages.append(exceptions.VALIDATION_ERROR_CLIENT_RENEGOTIATION)
@@ -595,6 +714,8 @@ class CertValidator(Validator):
             root_validator.verify()
             root_validator.verify_trust(trust_store)
             root_validator.pcidss_compliant()
+            root_validator.fips_compliant()
+            root_validator.nist_compliant()
             self.peer_validations.append(root_validator)
             self._root_certs.append(cert.get_serial_number())
 
@@ -683,6 +804,8 @@ class CertValidator(Validator):
                 peer_validator.verify()
                 self.validation_checks[VALIDATION_REVOCATION] = self.validation_checks.get(VALIDATION_REVOCATION) is not False
                 peer_validator.pcidss_compliant()
+                peer_validator.fips_compliant()
+                peer_validator.nist_compliant()
                 self.peer_validations.append(peer_validator)
 
         return all([self.certificate_valid, self.certificate_chain_valid])
